==> react-native-bugsee-5.4.1.tgz: package/scripts/hermes-sourcemaps.sh <==
#!/bin/bash
# Copyright (c) Bugsee, Inc.

set -x

THIS_SCRIPT_PATH="$(readlink -f "${BASH_SOURCE[0]}")"
SCRIPTS_DIR="$(dirname "$THIS_SCRIPT_PATH")"
MODULE_DIR=$(dirname $SCRIPTS_DIR)


# ------------------------------------------------------------------------
# Due to a bug in React Native shel script
# (see for detals: https://github.com/facebook/react-native/issues/32497)
# we can't just add an instructions to generate the Hermes sourcemap. Hence,
# we're obligated to reproduce the broken steps with fixes and get the
# correct results
#
# REGION: REACT NATIVE EXTRACTED CODE
# ------------------------------------------------------------------------

# if SOURCEMAP_FILE is not specified, trigger its generation
if [[ -z "$SOURCEMAP_FILE" ]]; then
    REACT_NATIVE_DIR="$(readlink -f "${MODULE_DIR}/../react-native")"
    COMPOSE_SOURCEMAP_PATH="$REACT_NATIVE_DIR/scripts/compose-source-maps.js"

    BUGSEE_HERMES_ENGINE_PATH="$PODS_ROOT/hermes-engine"
    BUGSEE_HERMES_CLI_PATH="$BUGSEE_HERMES_ENGINE_PATH/destroot/bin/hermesc"

    BUGSEE_USE_HERMES=false
    if [[ $USE_HERMES == true ]]; then
        BUGSEE_USE_HERMES=true
    else
      if [[ -z "$USE_HERMES" && -f "$BUGSEE_HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=true
      fi

      if [[ -f "$HERMES_ENGINE_PATH" && ! -f "$HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=false
      fi
    fi

    if [[ $BUGSEE_USE_HERMES == true ]]; then
        # picked from React Native build script
        DEST=$CONFIGURATION_BUILD_DIR/$UNLOCALIZED_RESOURCES_FOLDER_PATH
        # sourcemap is placed alongside the bundle itself
        HBC_SOURCEMAP_FILE="$DEST/main.jsbundle.map"
        # final sourcemap path
        FINAL_SOURCEMAP_FILE="$CONFIGURATION_TEMP_DIR/final-composed.jsbundle.map"

        # finally, merge the Packager and Hermes sourcemaps
        "$BUGSEE_ORIGINAL_NODE_BINARY" "$COMPOSE_SOURCEMAP_PATH" "$BUGSEE_PACKAGER_SOURCEMAP_FILE" "$HBC_SOURCEMAP_FILE" -o "$FINAL_SOURCEMAP_FILE"

        export BUGSEE_FINAL_SOURCEMAP_FILE="$FINAL_SOURCEMAP_FILE"
    fi
else
    export BUGSEE_FINAL_SOURCEMAP_FILE="$SOURCEMAP_FILE"
fi

# ------------------------------------------------------------------------
# ENDREGION: REACT NATIVE EXTRACTED CODE
# ------------------------------------------------------------------------

==> react-native-bugsee-5.5.2.tgz: package/scripts/hermes-sourcemaps.sh <==
#!/bin/bash
# Copyright (c) Bugsee, Inc.

set -x

THIS_SCRIPT_PATH="$(readlink -f "${BASH_SOURCE[0]}")"
SCRIPTS_DIR="$(dirname "$THIS_SCRIPT_PATH")"
MODULE_DIR=$(dirname $SCRIPTS_DIR)


# ------------------------------------------------------------------------
# Due to a bug in React Native shel script
# (see for detals: https://github.com/facebook/react-native/issues/32497)
# we can't just add an instructions to generate the Hermes sourcemap. Hence,
# we're obligated to reproduce the broken steps with fixes and get the
# correct results
#
# REGION: REACT NATIVE EXTRACTED CODE
# ------------------------------------------------------------------------

# if SOURCEMAP_FILE is not specified, trigger its generation
if [[ -z "$SOURCEMAP_FILE" ]]; then
    REACT_NATIVE_DIR="$(readlink -f "${MODULE_DIR}/../react-native")"
    COMPOSE_SOURCEMAP_PATH="$REACT_NATIVE_DIR/scripts/compose-source-maps.js"

    BUGSEE_HERMES_ENGINE_PATH="$PODS_ROOT/hermes-engine"
    BUGSEE_HERMES_CLI_PATH="$BUGSEE_HERMES_ENGINE_PATH/destroot/bin/hermesc"

    BUGSEE_USE_HERMES=false
    if [[ $USE_HERMES == true ]]; then
        BUGSEE_USE_HERMES=true
    else
      if [[ -z "$USE_HERMES" && -f "$BUGSEE_HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=true
      fi

      if [[ -f "$HERMES_ENGINE_PATH" && ! -f "$HERMES_CLI_PATH" ]]; then
          BUGSEE_USE_HERMES=false
      fi
    fi

    if [[ $BUGSEE_USE_HERMES == true ]]; then
        # picked from React Native build script
        DEST=$CONFIGURATION_BUILD_DIR/$UNLOCALIZED_RESOURCES_FOLDER_PATH
        # sourcemap is placed alongside the bundle itself
        HBC_SOURCEMAP_FILE="$DEST/main.jsbundle.map"
        # final sourcemap path
        FINAL_SOURCEMAP_FILE="$CONFIGURATION_TEMP_DIR/final-composed.jsbundle.map"

        # check whether the sourcemap file exists
        if [[ ! -f "$BUGSEE_PACKAGER_SOURCEMAP_FILE" ]]; then
            # if the sourcemap file does not exist, switch to
            # the one in the build dir
            export BUGSEE_PACKAGER_SOURCEMAP_FILE="$CONFIGURATION_BUILD_DIR/$UNLOCALIZED_RESOURCES_FOLDER_PATH/main.jsbundle.map"
        fi

        # finally, merge the Packager and Hermes sourcemaps
        "$BUGSEE_ORIGINAL_NODE_BINARY" --no-deprecation "$COMPOSE_SOURCEMAP_PATH" "$BUGSEE_PACKAGER_SOURCEMAP_FILE" "$HBC_SOURCEMAP_FILE" -o "$FINAL_SOURCEMAP_FILE"

        export BUGSEE_FINAL_SOURCEMAP_FILE="$FINAL_SOURCEMAP_FILE"
    fi
else
    export BUGSEE_FINAL_SOURCEMAP_FILE="$SOURCEMAP_FILE"
fi

# ------------------------------------------------------------------------
# ENDREGION: REACT NATIVE EXTRACTED CODE
# ------------------------------------------------------------------------
